@@ -23,30 +23,30 @@ def teardown_test(utils):
 
 def helper_test_list_sub_cmd(utils, sub_cmd):
     ret = utils.run(['tdnf', 'list', sub_cmd])
-    assert(ret['retval'] == 0)
+    assert ret['retval'] == 0
     ret = utils.run(['tdnf', 'list', sub_cmd, utils.config["sglversion_pkgname"]])
-    assert(ret['retval'] == 0)
+    assert ret['retval'] == 0
     ret = utils.run(['tdnf', 'list', sub_cmd, 'invalid_package'])
-    assert(ret['retval'] == 1011)
+    assert ret['retval'] == 1011
 
 
 def test_list_top(utils):
     spkg = utils.config["sglversion_pkgname"]
     ret = utils.run(['tdnf', 'install', '-y', spkg])
-    assert(ret['retval'] == 0)
+    assert ret['retval'] == 0
 
     ret = utils.run(['tdnf', 'list'])
-    assert(ret['retval'] == 0)
+    assert ret['retval'] == 0
     ret = utils.run(['tdnf', 'list', utils.config["sglversion_pkgname"]])
-    assert(ret['retval'] == 0)
+    assert ret['retval'] == 0
     ret = utils.run(['tdnf', 'list', 'invalid_package'])
-    assert(ret['retval'] == 1011)
+    assert ret['retval'] == 1011
 
 
 def test_list_sub_cmd(utils):
     spkg = utils.config["sglversion_pkgname"]
     ret = utils.run(['tdnf', 'install', '-y', spkg])
-    assert(ret['retval'] == 0)
+    assert ret['retval'] == 0
 
     helper_test_list_sub_cmd(utils, 'all')
     helper_test_list_sub_cmd(utils, 'installed')
@@ -59,7 +59,7 @@ def test_list_sub_cmd(utils):
 def test_list_options(utils):
     spkg = utils.config["sglversion_pkgname"]
     ret = utils.run(['tdnf', 'install', '-y', spkg])
-    assert(ret['retval'] == 0)
+    assert ret['retval'] == 0
 
     helper_test_list_sub_cmd(utils, '--all')
     helper_test_list_sub_cmd(utils, '--installed')
@@ -75,16 +75,16 @@ def test_list_notinstalled(utils):
     spkg = utils.config["sglversion_pkgname"]
 
     ret = utils.run(['tdnf', 'list', 'upgrades'])
-    assert(ret['retval'] == 0)
+    assert ret['retval'] == 0
 
     utils.run(['tdnf', 'install', '-y', '--nogpgcheck', mpkg + '-' + mpkg_version])
     ret = utils.run(['tdnf', 'list', 'upgrades', mpkg])
-    assert(len(ret['stdout']) == 1)
+    assert len(ret['stdout']) == 1
 
     for cmd in ['updates', 'upgrades', 'downgrades', '--updates', '--upgrades', '--downgrades']:
         ret = utils.run(['tdnf', 'list', cmd, 'invalid_package'])
-        assert(ret['retval'] == 1011)
+        assert ret['retval'] == 1011
 
         # spkg is not installed, expect error
         ret = utils.run(['tdnf', 'list', cmd, spkg])
-        assert(ret['retval'] == 1011)
+        assert ret['retval'] == 1011
