@@ -21,22 +21,22 @@ def teardown_test(utils):
 
 def test_whatprovides_no_arg(utils):
     ret = utils.run(['tdnf', 'whatprovides'])
-    assert(ret['retval'] == 907)
+    assert ret['retval'] == 907
 
 
 def test_whatprovides_invalid_arg(utils):
     ret = utils.run(['tdnf', 'whatprovides', 'invalid_arg'])
-    assert(ret['stderr'][0] == 'No data available')
+    assert ret['stderr'][0] == 'No data available'
 
 
 def test_whatprovides_valid_file_notinstalled(utils):
     ret = utils.run(['tdnf', 'whatprovides', '/lib/systemd/system/tdnf-test-one.service'])
-    assert('tdnf-test-one' in "\n".join(ret['stdout']))
-    assert(ret['retval'] == 0)
+    assert 'tdnf-test-one' in "\n".join(ret['stdout'])
+    assert ret['retval'] == 0
 
 
 def test_whatprovides_valid_file_installed(utils):
     ret = utils.run(['tdnf', 'install', '-y', '--nogpgcheck', 'tdnf-test-one'])
     ret = utils.run(['tdnf', 'whatprovides', '/lib/systemd/system/tdnf-test-one.service'])
-    assert('tdnf-test-one' in "\n".join(ret['stdout']))
-    assert(ret['retval'] == 0)
+    assert 'tdnf-test-one' in "\n".join(ret['stdout'])
+    assert ret['retval'] == 0
